@@ -31,7 +31,7 @@
 #include <KPluginFactory>
 #include <KPluginMetaData>
 
-#include <KActivities/Consumer>
+#include <PlasmaActivities/Consumer>
 
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
@@ -99,11 +99,11 @@ void Core::onBackendReady()
 
     const bool isMobile = Kirigami::Platform::TabletModeWatcher::self()->isTabletMode();
     const bool isVM = PowerDevil::PowerManagement::instance()->isVirtualMachine();
-    const bool canSuspendToRam = m_suspendController->canSuspend();
-    const bool canSuspendToDisk = m_suspendController->canHibernate();
+    const bool canSuspend = m_suspendController->canSuspend();
+    const bool canHibernate = m_suspendController->canHibernate();
 
-    PowerDevil::migrateConfig(isMobile, isVM, canSuspendToRam);
-    m_globalSettings = new PowerDevil::GlobalSettings(canSuspendToRam, canSuspendToDisk, this);
+    PowerDevil::migrateConfig(isMobile, isVM, canSuspend);
+    m_globalSettings = new PowerDevil::GlobalSettings(canSuspend, canHibernate, this);
 
     // Get the battery devices ready
     {
@@ -609,7 +609,7 @@ void Core::handleCriticalBattery(int percent)
         m_criticalBatteryTimer->start();
         break;
     }
-    case PowerButtonAction::SuspendToDisk: {
+    case PowerButtonAction::Hibernate: {
         m_criticalBatteryNotification->setText(i18n("Battery level critical. Your computer will enter hibernation mode in 60 seconds."));
         auto action = m_criticalBatteryNotification->addAction(
             i18nc("@action:button Enter hibernation mode without waiting for the battery critical timer", "Hibernate Now"));
@@ -617,8 +617,7 @@ void Core::handleCriticalBattery(int percent)
         m_criticalBatteryTimer->start();
         break;
     }
-    case PowerButtonAction::SuspendToRam:
-    case PowerButtonAction::SuspendHybrid: {
+    case PowerButtonAction::Sleep: {
         m_criticalBatteryNotification->setText(i18n("Battery level critical. Your computer will go to sleep in 60 seconds."));
         auto action =
             m_criticalBatteryNotification->addAction(i18nc("@action:button Suspend to ram without waiting for the battery critical timer", "Sleep Now"));
@@ -1148,7 +1147,6 @@ void Core::timerfdEventHandler()
     // send it away
     QDBusConnection::sessionBus().call(msg, QDBus::NoBlock);
 }
-
 }
 
 #include "moc_powerdevilcore.cpp"
